@@ -121,7 +121,7 @@ class SystemModel(object):
         def is_valid_path(value):
             if value is None:
                 return False
-            return re.compile('^/(([a-zA-Z0-9\.\-]+)/?)*?$').match(value) is not None
+            return re.compile('^/(([a-zA-Z0-9\.\-_]+)/?)*?$').match(value) is not None
 
         errors = []
         if not is_alphanumeric(self.id):
@@ -134,7 +134,7 @@ class SystemModel(object):
             errors.append(('auth_method', 'Unknown auth type.'))
         else:
             if self.auth_method == self.AUTH_METHOD_PUBLIC_KEY:
-                if not is_valid_path(self.ssh_key):
+                if not os.path.exists(self.ssh_key):
                     errors.append(('ssh_key', 'Invalid ssh key path.'))
         if not is_alphanumeric(self.user):
             errors.append(('user', 'Usernames can only contain letters and digits.'))
